@@ -2,27 +2,40 @@
 #ifndef PVR350_DEVICE_H
 #define PVR350_DEVICE_H
 
-#include "mpeg2decoder.h"
 #include <vdr/device.h>
 #include <vdr/thread.h>
 #include "pvr350osd.h"
+#include "writer.h"
 
 class cPvr350Device: public cDevice {
 private:
     int       fd_out;
     int       fbfd;
     int       mute;
-    int storedglobalalpha;
+    int       storedglobalalpha;
     unsigned long initglobalalpha;
-    int osdbufsize;
+    int       osdbufsize;
     unsigned char *osdbuffer;
     unsigned char *osdbuf_aligned;
-    int stride;
+    int       stride;
     int       output_mode;
 
 
     ePlayMode m_PlayMode;  
-    cMpeg2Decoder  *decoder;
+    cSpuDecoder        *spuDecoder;
+
+    cRingBufferLinear *m_RingBuffer;
+
+    /* Needed for the demuxing */
+    int  state, payload, streamtype;
+    unsigned char header[6];     
+    unsigned int syncword;
+
+    /* Current sizes of the display */
+    unsigned int   current_horiz;
+    unsigned int   current_vertical;
+
+    void SetVidInfo(const uchar *mbuf, int count);
 
 public:
     cPvr350Device(void);
@@ -49,6 +62,9 @@ public:
 
     virtual bool Poll(cPoller &Poller, int TimeoutMs = 0);
     virtual cOsdBase *NewOsd(int x, int y);
+    virtual cSpuDecoder *GetSpuDecoder(void);
+
+
 };
 
 #endif
