@@ -15,6 +15,6 @@ public:
     virtual void CommitWindow(cWindow *Window);
     virtual void ShowWindow(cWindow *Window);
     virtual void HideWindow(cWindow *Window, bool Hide);
-    virtual void MoveWindow(cWindow *Window, int X, int Y);
     virtual void CloseWindow(cWindow *Window);
+    virtual void MoveWindow(cWindow *Window, int x, int y);
 };
